@@ -28,6 +28,7 @@ fake = faker.Faker()
 
 class BaseGameExperience(models.Model):
     name = models.CharField(max_length=100)
+    experience_id = models.UUIDField(db_index=True, blank=True, null=True)
     date_created = models.DateTimeField(editable=False, default=timezone.now)
     version = models.CharField(max_length=20, blank=True)
     continuous = models.BooleanField(
@@ -37,6 +38,9 @@ class BaseGameExperience(models.Model):
         "If unset, this become configurable at the run level.",
     )
 
+    objects = managers.GameExperienceManager()
+    _default_manager: managers.GameExperienceManager
+
     class Meta:
         abstract = True
         ordering = "-date_created"
@@ -50,6 +54,13 @@ class BaseGameExperience(models.Model):
     def new_instance_name():
         return " ".join(fake.words(3)).title()
 
+    @cached_property
+    def is_latest(self):
+        if not self.experience_id:
+            return True
+        games = type(self)._default_manager.from_experience_id(self.experience_id)
+        return self == games[-1] if games else True
+
 
 class GameExperience(BaseGameExperience):
     """
